@@ -46,10 +46,7 @@ get_file_content (GFile *file,
 	gchar *text, *uri, *path;
 	int fd;
 
-	/* If no content requested, return */
-	if (n_bytes == 0) {
-		return NULL;
-	}
+	g_return_val_if_fail (n_bytes > 0, NULL);
 
 	uri = g_file_get_uri (file);
 
@@ -85,12 +82,20 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 {
 	TrackerResource *metadata;
 	TrackerConfig *config;
-	gchar *content;
+	gsize n_bytes;
+	gchar *content = NULL;
 
 	config = tracker_main_get_config ();
 
-	content = get_file_content (tracker_extract_info_get_file (info),
-	                            tracker_config_get_max_bytes (config));
+	n_bytes = tracker_config_get_max_bytes (config);
+	if (n_bytes > 0) {
+		content = get_file_content (tracker_extract_info_get_file (info), n_bytes);
+
+		if (content == NULL) {
+			/* An error occurred, perhaps the file was deleted. */
+			return FALSE;
+		}
+	}
 
 	metadata = tracker_resource_new (NULL);
 	tracker_resource_add_uri (metadata, "rdf:type", "nfo:PlainTextDocument");
