@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python3
 #
 # Copyright (C) 2010, Nokia <jean-luc.lamadon@nokia.com>
 #
@@ -27,26 +27,32 @@ import subprocess
 import time
 import re
 
-import configuration as cfg
-import mainloop
-import options
+from common.utils import configuration as cfg
+from common.utils import mainloop
+from common.utils import options
+
 
 class NoMetadataException (Exception):
     pass
 
+
 REASONABLE_TIMEOUT = 30
 
-def log (message):
-    if options.is_verbose ():
+
+def log(message):
+    if options.is_verbose():
         print (message)
 
 
 _process_list = []
 
+
 def _cleanup_processes():
     for process in _process_list:
         log("helpers._cleanup_processes: stopping %s" % process)
         process.stop()
+
+
 atexit.register(_cleanup_processes)
 
 
@@ -69,7 +75,7 @@ class Helper:
     BUS_NAME = None
     PROCESS_NAME = None
 
-    def __init__ (self):
+    def __init__(self):
         self.process = None
         self.available = False
 
@@ -77,45 +83,45 @@ class Helper:
 
         self.bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
 
-    def _start_process (self):
+    def _start_process(self):
         global _process_list
         _process_list.append(self)
 
         path = self.PROCESS_PATH
-        flags = getattr (self,
-                         "FLAGS",
-                         [])
+        flags = getattr(self,
+                        "FLAGS",
+                        [])
 
         kws = {}
 
-        if not options.is_verbose ():
-            FNULL = open ('/dev/null', 'w')
-            kws = { 'stdout': FNULL, 'stderr': subprocess.PIPE }
+        if not options.is_verbose():
+            FNULL = open('/dev/null', 'w')
+            kws = {'stdout': FNULL, 'stderr': subprocess.PIPE}
 
         command = [path] + flags
-        log ("Starting %s" % ' '.join(command))
+        log("Starting %s" % ' '.join(command))
         try:
-            return subprocess.Popen ([path] + flags, **kws)
+            return subprocess.Popen([path] + flags, **kws)
         except OSError as e:
             raise RuntimeError("Error starting %s: %s" % (path, e))
 
     def _bus_name_appeared(self, name, owner, data):
-        log ("[%s] appeared in the bus as %s" % (self.PROCESS_NAME, owner))
+        log("[%s] appeared in the bus as %s" % (self.PROCESS_NAME, owner))
         self.available = True
         self.loop.quit()
 
     def _bus_name_vanished(self, name, data):
-        log ("[%s] disappeared from the bus" % self.PROCESS_NAME)
+        log("[%s] disappeared from the bus" % self.PROCESS_NAME)
         self.available = False
         self.loop.quit()
 
-    def _process_watch_cb (self):
+    def _process_watch_cb(self):
         if self.process_watch_timeout == 0 or self.process is None:
             # The GLib seems to call the timeout after we've removed it
             # sometimes, which causes errors unless we detect it.
             return False
 
-        status = self.process.poll ()
+        status = self.process.poll()
 
         if status is None:
             return True    # continue
@@ -129,13 +135,13 @@ class Helper:
                 error = self.process.stderr.read()
             raise RuntimeError("%s exited with status: %i\n%s" % (self.PROCESS_NAME, status, error))
 
-    def _timeout_on_idle_cb (self):
-        log ("[%s] Timeout waiting... asumming idle." % self.PROCESS_NAME)
-        self.loop.quit ()
+    def _timeout_on_idle_cb(self):
+        log("[%s] Timeout waiting... asumming idle." % self.PROCESS_NAME)
+        self.loop.quit()
         self.timeout_id = None
         return False
 
-    def start (self):
+    def start(self):
         """
         Start an instance of process and wait for it to appear on the bus.
         """
@@ -153,21 +159,21 @@ class Helper:
         else:
             if self.available:
                 # It's running, but we didn't start it...
-                raise Exception ("Unable to start test instance of %s: "
-                                 "already running " % self.PROCESS_NAME)
+                raise Exception("Unable to start test instance of %s: "
+                                "already running " % self.PROCESS_NAME)
 
-            self.process = self._start_process ()
-            log ('[%s] Started process %i' % (self.PROCESS_NAME, self.process.pid))
-            self.process_watch_timeout = GLib.timeout_add (200, self._process_watch_cb)
+            self.process = self._start_process()
+            log('[%s] Started process %i' % (self.PROCESS_NAME, self.process.pid))
+            self.process_watch_timeout = GLib.timeout_add(200, self._process_watch_cb)
 
         self.abort_if_process_exits_with_status_0 = True
 
         # Run the loop until the bus name appears, or the process dies.
-        self.loop.run_checked ()
+        self.loop.run_checked()
 
         self.abort_if_process_exits_with_status_0 = False
 
-    def stop (self):
+    def stop(self):
         global _process_list
 
         if self.process is None:
@@ -185,42 +191,42 @@ class Helper:
                 time.sleep(0.1)
 
                 if time.time() > (start + REASONABLE_TIMEOUT):
-                    log ("[%s] Failed to terminate, sending kill!" % self.PROCESS_NAME)
+                    log("[%s] Failed to terminate, sending kill!" % self.PROCESS_NAME)
                     self.process.kill()
                     self.process.wait()
 
-            log ("[%s] stopped." % self.PROCESS_NAME)
+            log("[%s] stopped." % self.PROCESS_NAME)
 
             # Run the loop until the bus name disappears, or the process dies.
-            self.loop.run_checked ()
+            self.loop.run_checked()
             Gio.bus_unwatch_name(self._bus_name_watch_id)
 
         self.process = None
         _process_list.remove(self)
 
-
-    def kill (self):
+    def kill(self):
         global _process_list
 
         if options.is_manual_start():
-            log ("kill(): ignoring, because process was started manually.")
+            log("kill(): ignoring, because process was started manually.")
             return
 
-        self.process.kill ()
+        self.process.kill()
 
         # Name owner changed callback should take us out from this loop
-        self.loop.run_checked ()
+        self.loop.run_checked()
         Gio.bus_unwatch_name(self._bus_name_watch_id)
 
         self.process = None
         _process_list.remove(self)
 
-        log ("[%s] killed." % self.PROCESS_NAME)
+        log("[%s] killed." % self.PROCESS_NAME)
 
 
 class GraphUpdateTimeoutException(RuntimeError):
     pass
 
+
 class StoreHelper (Helper):
     """
     Wrapper for the Store API
@@ -233,8 +239,8 @@ class StoreHelper (Helper):
     PROCESS_PATH = cfg.TRACKER_STORE_PATH
     BUS_NAME = cfg.TRACKER_BUSNAME
 
-    def start (self):
-        Helper.start (self)
+    def start(self):
+        Helper.start(self)
 
         self.resources = Gio.DBusProxy.new_sync(
             self.bus, Gio.DBusProxyFlags.DO_NOT_AUTO_START, None,
@@ -252,11 +258,11 @@ class StoreHelper (Helper):
             self.bus, Gio.DBusProxyFlags.DO_NOT_AUTO_START, None,
             cfg.TRACKER_BUSNAME, cfg.TRACKER_STATUS_OBJ_PATH, cfg.STATUS_IFACE)
 
-        log ("[%s] booting..." % self.PROCESS_NAME)
-        self.status_iface.Wait ()
-        log ("[%s] ready." % self.PROCESS_NAME)
+        log("[%s] booting..." % self.PROCESS_NAME)
+        self.status_iface.Wait()
+        log("[%s] ready." % self.PROCESS_NAME)
 
-        self.reset_graph_updates_tracking ()
+        self.reset_graph_updates_tracking()
 
         def signal_handler(proxy, sender_name, signal_name, parameters):
             if signal_name == 'GraphUpdated':
@@ -265,8 +271,8 @@ class StoreHelper (Helper):
         self.graph_updated_handler_id = self.resources.connect(
             'g-signal', signal_handler)
 
-    def stop (self):
-        Helper.stop (self)
+    def stop(self):
+        Helper.stop(self)
 
         if self.graph_updated_handler_id != 0:
             self.resources.disconnect(self.graph_updated_handler_id)
@@ -277,17 +283,17 @@ class StoreHelper (Helper):
     # the list of events already received and wait for more if the event has
     # not yet happened.
 
-    def reset_graph_updates_tracking (self):
+    def reset_graph_updates_tracking(self):
         self.class_to_track = None
         self.inserts_list = []
         self.deletes_list = []
         self.inserts_match_function = None
         self.deletes_match_function = None
 
-    def _graph_updated_timeout_cb (self):
+    def _graph_updated_timeout_cb(self):
         raise GraphUpdateTimeoutException()
 
-    def _graph_updated_cb (self, class_name, deletes_list, inserts_list):
+    def _graph_updated_cb(self, class_name, deletes_list, inserts_list):
         """
         Process notifications from tracker-store on resource changes.
         """
@@ -299,26 +305,26 @@ class StoreHelper (Helper):
             if inserts_list is not None:
                 if self.inserts_match_function is not None:
                     # The match function will remove matched entries from the list
-                    (exit_loop, inserts_list) = self.inserts_match_function (inserts_list)
+                    (exit_loop, inserts_list) = self.inserts_match_function(inserts_list)
                 self.inserts_list += inserts_list
 
             if not exit_loop and deletes_list is not None:
                 if self.deletes_match_function is not None:
-                    (exit_loop, deletes_list) = self.deletes_match_function (deletes_list)
+                    (exit_loop, deletes_list) = self.deletes_match_function(deletes_list)
                 self.deletes_list += deletes_list
 
             if exit_loop:
                 GLib.source_remove(self.graph_updated_timeout_id)
                 self.graph_updated_timeout_id = 0
-                self.loop.quit ()
+                self.loop.quit()
         else:
             log("Ignoring GraphUpdated for class %s, currently tracking %s" % (class_name, self.class_to_track))
 
-    def _enable_await_timeout (self):
-        self.graph_updated_timeout_id = GLib.timeout_add_seconds (REASONABLE_TIMEOUT,
-                                                                  self._graph_updated_timeout_cb)
+    def _enable_await_timeout(self):
+        self.graph_updated_timeout_id = GLib.timeout_add_seconds(REASONABLE_TIMEOUT,
+                                                                 self._graph_updated_timeout_cb)
 
-    def await_resource_inserted (self, rdf_class, url = None, title = None, required_property = None):
+    def await_resource_inserted(self, rdf_class, url=None, title=None, required_property=None):
         """
         Block until a resource matching the parameters becomes available
         """
@@ -330,13 +336,13 @@ class StoreHelper (Helper):
         self.matched_resource_urn = None
         self.matched_resource_id = None
 
-        log ("Await new %s (%i existing inserts)" % (rdf_class, len (self.inserts_list)))
+        log("Await new %s (%i existing inserts)" % (rdf_class, len(self.inserts_list)))
 
         if required_property is not None:
             required_property_id = self.get_resource_id_by_uri(required_property)
-            log ("Required property %s id %i" % (required_property, required_property_id))
+            log("Required property %s id %i" % (required_property, required_property_id))
 
-        def find_resource_insertion (inserts_list):
+        def find_resource_insertion(inserts_list):
             matched_creation = (self.matched_resource_id is not None)
             matched_required_property = False
             remaining_events = []
@@ -357,23 +363,23 @@ class StoreHelper (Helper):
                         where += "; nie:title \"%s\"" % title
 
                     query = "SELECT ?urn WHERE { %s FILTER (tracker:id(?urn) = %s)}" % (where, insert[1])
-                    result_set = self.query (query)
+                    result_set = self.query(query)
 
-                    if len (result_set) > 0:
+                    if len(result_set) > 0:
                         matched_creation = True
                         self.matched_resource_urn = result_set[0][0]
                         self.matched_resource_id = insert[1]
-                        log ("Matched creation of resource %s (%i)" %
-                             (self.matched_resource_urn,
-                              self.matched_resource_id))
+                        log("Matched creation of resource %s (%i)" %
+                            (self.matched_resource_urn,
+                             self.matched_resource_id))
                         if required_property is not None:
-                            log ("Waiting for property %s (%i) to be set" %
-                                 (required_property, required_property_id))
+                            log("Waiting for property %s (%i) to be set" %
+                                (required_property, required_property_id))
 
                 if required_property is not None and matched_creation and not matched_required_property:
                     if id == self.matched_resource_id and insert[2] == required_property_id:
                         matched_required_property = True
-                        log ("Matched %s %s" % (self.matched_resource_urn, required_property))
+                        log("Matched %s %s" % (self.matched_resource_urn, required_property))
 
                 if not matched_creation or id != self.matched_resource_id:
                     remaining_events += [insert]
@@ -381,20 +387,20 @@ class StoreHelper (Helper):
             matched = matched_creation if required_property is None else matched_required_property
             return matched, remaining_events
 
-        def match_cb (inserts_list):
-            matched, remaining_events = find_resource_insertion (inserts_list)
+        def match_cb(inserts_list):
+            matched, remaining_events = find_resource_insertion(inserts_list)
             exit_loop = matched
             return exit_loop, remaining_events
 
         # Check the list of previously received events for matches
-        (existing_match, self.inserts_list) = find_resource_insertion (self.inserts_list)
+        (existing_match, self.inserts_list) = find_resource_insertion(self.inserts_list)
 
         if not existing_match:
-            self._enable_await_timeout ()
+            self._enable_await_timeout()
             self.inserts_match_function = match_cb
             # Run the event loop until the correct notification arrives
             try:
-                self.loop.run_checked ()
+                self.loop.run_checked()
             except GraphUpdateTimeoutException as e:
                 raise GraphUpdateTimeoutException("Timeout waiting for resource: class %s, URL %s, title %s" % (rdf_class, url, title))
             self.inserts_match_function = None
@@ -402,15 +408,15 @@ class StoreHelper (Helper):
         self.class_to_track = None
         return (self.matched_resource_id, self.matched_resource_urn)
 
-    def await_resource_deleted (self, rdf_class, id):
+    def await_resource_deleted(self, rdf_class, id):
         """
         Block until we are notified of a resources deletion
         """
         assert (self.deletes_match_function == None)
         assert (self.class_to_track == None)
 
-        def find_resource_deletion (deletes_list):
-            log ("find_resource_deletion: looking for %i in %s" % (id, deletes_list))
+        def find_resource_deletion(deletes_list):
+            log("find_resource_deletion: looking for %i in %s" % (id, deletes_list))
 
             matched = False
             remaining_events = []
@@ -423,30 +429,30 @@ class StoreHelper (Helper):
 
             return matched, remaining_events
 
-        def match_cb (deletes_list):
+        def match_cb(deletes_list):
             matched, remaining_events = find_resource_deletion(deletes_list)
             exit_loop = matched
             return exit_loop, remaining_events
 
-        log ("Await deletion of %i (%i existing)" % (id, len (self.deletes_list)))
+        log("Await deletion of %i (%i existing)" % (id, len(self.deletes_list)))
 
-        (existing_match, self.deletes_list) = find_resource_deletion (self.deletes_list)
+        (existing_match, self.deletes_list) = find_resource_deletion(self.deletes_list)
 
         if not existing_match:
-            self._enable_await_timeout ()
+            self._enable_await_timeout()
             self.class_to_track = rdf_class
             self.deletes_match_function = match_cb
             # Run the event loop until the correct notification arrives
             try:
-                self.loop.run_checked ()
+                self.loop.run_checked()
             except GraphUpdateTimeoutException:
-                raise GraphUpdateTimeoutException ("Resource %i has not been deleted." % id)
+                raise GraphUpdateTimeoutException("Resource %i has not been deleted." % id)
             self.deletes_match_function = None
             self.class_to_track = None
 
         return
 
-    def await_property_changed (self, rdf_class, subject_id, property_uri):
+    def await_property_changed(self, rdf_class, subject_id, property_uri):
         """
         Block until a property of a resource is updated or inserted.
         """
@@ -454,13 +460,13 @@ class StoreHelper (Helper):
         assert (self.deletes_match_function == None)
         assert (self.class_to_track == None)
 
-        log ("Await change to %i %s (%i, %i existing)" % (subject_id, property_uri, len(self.inserts_list), len(self.deletes_list)))
+        log("Await change to %i %s (%i, %i existing)" % (subject_id, property_uri, len(self.inserts_list), len(self.deletes_list)))
 
         self.class_to_track = rdf_class
 
         property_id = self.get_resource_id_by_uri(property_uri)
 
-        def find_property_change (event_list):
+        def find_property_change(event_list):
             matched = False
             remaining_events = []
 
@@ -473,22 +479,22 @@ class StoreHelper (Helper):
 
             return matched, remaining_events
 
-        def match_cb (event_list):
-            matched, remaining_events = find_property_change (event_list)
+        def match_cb(event_list):
+            matched, remaining_events = find_property_change(event_list)
             exit_loop = matched
             return exit_loop, remaining_events
 
         # Check the list of previously received events for matches
-        (existing_match, self.inserts_list) = find_property_change (self.inserts_list)
-        (existing_match, self.deletes_list) = find_property_change (self.deletes_list)
+        (existing_match, self.inserts_list) = find_property_change(self.inserts_list)
+        (existing_match, self.deletes_list) = find_property_change(self.deletes_list)
 
         if not existing_match:
-            self._enable_await_timeout ()
+            self._enable_await_timeout()
             self.inserts_match_function = match_cb
             self.deletes_match_function = match_cb
             # Run the event loop until the correct notification arrives
             try:
-                self.loop.run_checked ()
+                self.loop.run_checked()
             except GraphUpdateTimeoutException:
                 raise GraphUpdateTimeoutException(
                     "Timeout waiting for property change, subject %i property %s (%i)" % (subject_id, property_uri, property_id))
@@ -496,43 +502,43 @@ class StoreHelper (Helper):
             self.deletes_match_function = None
             self.class_to_track = None
 
-    def query (self, query, timeout=5000, **kwargs):
-        return self.resources.SparqlQuery ('(s)', query, timeout=timeout, **kwargs)
+    def query(self, query, timeout=5000, **kwargs):
+        return self.resources.SparqlQuery('(s)', query, timeout=timeout, **kwargs)
 
-    def update (self, update_sparql, timeout=5000, **kwargs):
-        return self.resources.SparqlUpdate ('(s)', update_sparql, timeout=timeout, **kwargs)
+    def update(self, update_sparql, timeout=5000, **kwargs):
+        return self.resources.SparqlUpdate('(s)', update_sparql, timeout=timeout, **kwargs)
 
-    def load (self, ttl_uri, timeout=5000, **kwargs):
-        return self.resources.Load ('(s)', ttl_uri, timeout=timeout, **kwargs)
+    def load(self, ttl_uri, timeout=5000, **kwargs):
+        return self.resources.Load('(s)', ttl_uri, timeout=timeout, **kwargs)
 
-    def batch_update (self, update_sparql, **kwargs):
-        return self.resources.BatchSparqlUpdate ('(s)', update_sparql, **kwargs)
+    def batch_update(self, update_sparql, **kwargs):
+        return self.resources.BatchSparqlUpdate('(s)', update_sparql, **kwargs)
 
-    def batch_commit (self, **kwargs):
-        return self.resources.BatchCommit (**kwargs)
+    def batch_commit(self, **kwargs):
+        return self.resources.BatchCommit(**kwargs)
 
-    def backup (self, backup_file, **kwargs):
-        return self.backup_iface.Save ('(s)', backup_file, **kwargs)
+    def backup(self, backup_file, **kwargs):
+        return self.backup_iface.Save('(s)', backup_file, **kwargs)
 
-    def restore (self, backup_file, **kwargs):
-        return self.backup_iface.Restore ('(s)', backup_file, **kwargs)
+    def restore(self, backup_file, **kwargs):
+        return self.backup_iface.Restore('(s)', backup_file, **kwargs)
 
-    def get_stats (self, **kwargs):
+    def get_stats(self, **kwargs):
         return self.stats_iface.Get(**kwargs)
 
-    def get_tracker_iface (self):
+    def get_tracker_iface(self):
         return self.resources
 
-    def count_instances (self, ontology_class):
+    def count_instances(self, ontology_class):
         QUERY = """
         SELECT COUNT(?u) WHERE {
             ?u a %s .
         }
         """
-        result = self.resources.SparqlQuery ('(s)', QUERY % (ontology_class))
+        result = self.resources.SparqlQuery('(s)', QUERY % (ontology_class))
 
-        if (len (result) == 1):
-            return int (result [0][0])
+        if (len(result) == 1):
+            return int(result[0][0])
         else:
             return -1
 
@@ -543,11 +549,11 @@ class StoreHelper (Helper):
         result = self.query(
             'SELECT tracker:id(%s) WHERE { }' % uri)
         if len(result) == 1:
-            return int (result [0][0])
+            return int(result[0][0])
         elif len(result) == 0:
-            raise Exception ("No entry for resource %s" % uri)
+            raise Exception("No entry for resource %s" % uri)
         else:
-            raise Exception ("Multiple entries for resource %s" % uri)
+            raise Exception("Multiple entries for resource %s" % uri)
 
     # FIXME: rename to get_resource_id_by_nepomuk_url !!
     def get_resource_id(self, url):
@@ -557,22 +563,22 @@ class StoreHelper (Helper):
         result = self.query(
             'SELECT tracker:id(?r) WHERE { ?r nie:url "%s" }' % url)
         if len(result) == 1:
-            return int (result [0][0])
+            return int(result[0][0])
         elif len(result) == 0:
-            raise Exception ("No entry for resource %s" % url)
+            raise Exception("No entry for resource %s" % url)
         else:
-            raise Exception ("Multiple entries for resource %s" % url)
+            raise Exception("Multiple entries for resource %s" % url)
 
-    def ask (self, ask_query):
-        assert ask_query.strip ().startswith ("ASK")
-        result = self.query (ask_query)
-        assert len (result) == 1
+    def ask(self, ask_query):
+        assert ask_query.strip().startswith("ASK")
+        result = self.query(ask_query)
+        assert len(result) == 1
         if result[0][0] == "true":
             return True
         elif result[0][0] == "false":
             return False
         else:
-            raise Exception ("Something fishy is going on")
+            raise Exception("Something fishy is going on")
 
 
 class WakeupCycleTimeoutException(RuntimeError):
@@ -587,15 +593,15 @@ class MinerFsHelper (Helper):
 
     FLAGS = ['--initial-sleep=0']
 
-    def __init__ (self):
+    def __init__(self):
         Helper.__init__(self)
         self._progress_handler_id = 0
         self._wakeup_count = 0
         self._previous_status = None
         self._target_wakeup_count = None
 
-    def start (self):
-        Helper.start (self)
+    def start(self):
+        Helper.start(self)
 
         self.miner_fs = Gio.DBusProxy.new_sync(
             self.bus, Gio.DBusProxyFlags.DO_NOT_AUTO_START, None,
@@ -610,13 +616,13 @@ class MinerFsHelper (Helper):
 
         self._progress_handler_id = self.miner_fs.connect('g-signal', signal_handler)
 
-    def stop (self):
-        Helper.stop (self)
+    def stop(self):
+        Helper.stop(self)
 
         if self._progress_handler_id != 0:
             self.miner_fs.disconnect(self._progress_handler_id)
 
-    def _progress_cb (self, status, progress, remaining_time):
+    def _progress_cb(self, status, progress, remaining_time):
         if self._previous_status is None:
             self._previous_status = status
         if self._previous_status != 'Idle' and status == 'Idle':
@@ -629,7 +635,7 @@ class MinerFsHelper (Helper):
         """Return the number of wakeup-to-idle cycles the miner-fs completed."""
         return self._wakeup_count
 
-    def await_wakeup_count (self, target_wakeup_count, timeout=REASONABLE_TIMEOUT):
+    def await_wakeup_count(self, target_wakeup_count, timeout=REASONABLE_TIMEOUT):
         """Block until the miner has completed N wakeup-and-idle cycles.
 
         This function is for use by miner-fs tests that should trigger an
@@ -653,20 +659,20 @@ class MinerFsHelper (Helper):
         assert self._target_wakeup_count is None
 
         if self._wakeup_count >= target_wakeup_count:
-            log ("miner-fs wakeup count is at %s (target is %s). No need to wait" % (self._wakeup_count, target_wakeup_count))
+            log("miner-fs wakeup count is at %s (target is %s). No need to wait" % (self._wakeup_count, target_wakeup_count))
         else:
-            def _timeout_cb ():
+            def _timeout_cb():
                 raise WakeupCycleTimeoutException()
-            timeout_id = GLib.timeout_add_seconds (timeout, _timeout_cb)
+            timeout_id = GLib.timeout_add_seconds(timeout, _timeout_cb)
 
-            log ("Waiting for miner-fs wakeup count of %s (currently %s)" % (target_wakeup_count, self._wakeup_count))
+            log("Waiting for miner-fs wakeup count of %s (currently %s)" % (target_wakeup_count, self._wakeup_count))
             self._target_wakeup_count = target_wakeup_count
             self.loop.run_checked()
 
             self._target_wakeup_count = None
             GLib.source_remove(timeout_id)
 
-    def index_file (self, uri):
+    def index_file(self, uri):
         return self.index.IndexFile('(s)', uri)
 
 
